summaryrefslogtreecommitdiff
path: root/tikzit/src/gtk/NodeStyleSelector.h
diff options
context:
space:
mode:
Diffstat (limited to 'tikzit/src/gtk/NodeStyleSelector.h')
-rw-r--r--tikzit/src/gtk/NodeStyleSelector.h34
1 files changed, 13 insertions, 21 deletions
diff --git a/tikzit/src/gtk/NodeStyleSelector.h b/tikzit/src/gtk/NodeStyleSelector.h
index 894d71e..a699dc8 100644
--- a/tikzit/src/gtk/NodeStyleSelector.h
+++ b/tikzit/src/gtk/NodeStyleSelector.h
@@ -17,14 +17,14 @@
#import "TZFoundation.h"
#import <gtk/gtk.h>
-#import "StyleManager.h"
+
+@class NodeStyle;
+@class NodeStylesModel;
+@class StyleManager;
@interface NodeStyleSelector: NSObject {
- GtkListStore *store;
+ NodeStylesModel *model;
GtkIconView *view;
- StyleManager *styleManager;
- BOOL linkedToActiveStyle;
- BOOL suppressSetActiveStyle;
}
/*!
@@ -34,35 +34,27 @@
@property (readonly) GtkWidget *widget;
/*!
- @property manager
- @brief The StyleManager to use. Default is [StyleManager manager]
- */
-@property (retain) StyleManager *styleManager;
-
-/*!
- @property linkedToActiveStyles
- @brief Whether the current selection should be the same as the
- style manager's active style
+ @property model
+ @brief The model to use.
*/
-@property (getter=isLinkedToActiveStyle) BOOL linkedToActiveStyle;
+@property (retain) NodeStylesModel *model;
/*!
@property selectedStyle
- @brief The selected style. If linkedToActiveStyle is YES, this
- will be the same as [manager activeStyle].
+ @brief The selected style.
When this changes, a SelectedStyleChanged notification will be posted
*/
@property (assign) NodeStyle *selectedStyle;
/*!
* Initialise with the default style manager
*/
-- (id) init;
+- (id) initWithStyleManager:(StyleManager*)manager;
/*!
* Initialise with the given style manager
*/
-- (id) initWithStyleManager:(StyleManager*)m;
+- (id) initWithModel:(NodeStylesModel*)model;
@end
@@ -34,35 +34,27 @@
/*!
- * Initialise with the default style manager
+ * Initialise with a new model for the given style manager
*/
@@ -34,35 +34,27 @@
/*!
- * Initialise with the given style manager
+ * Initialise with the given model
*/